@@ -18,6 +18,9 @@ class ChatAPI:
             self.load_config()
         except FileNotFoundError:
 
+            print(f'Config file not found at "{self.config_file}".')
+            print(f'Creating new config file at "{self.config_file}".')
+
             self.config = {
                 "ErrorOnBadToken": False,
                 "header": {"Content-Type": "application/json"},
@@ -243,6 +246,12 @@ def token_refresh():
 
     Equivalent to doing `ChatAPI().get_token()`.
     """
-    # from sys import path
 
-    ChatAPI().get_token()
+    from sys import path
+
+    try:
+        with open(f"{path[0]}/config.json"):
+            pass
+        ChatAPI().get_token()
+    except FileNotFoundError:
+        ChatAPI()
